Method: LibXML::XML::Node#sibling=

Defined in:
ext/libxml/ruby_xml_node.c

#sibling=(node) ⇒ Object

Adds the specified node as the end of the current node’s list of siblings. If the node already exists in the document, it is first removed from its existing context. Any adjacent text nodes will be merged together, meaning the returned node may be different than the original node.



1125
1126
1127
1128
# File 'ext/libxml/ruby_xml_node.c', line 1125

static VALUE rxml_node_sibling_set(VALUE self, VALUE sibling)
{
  return rxml_node_modify_dom(self, sibling, xmlAddSibling);
}