Class: LibXML::XML::Dtd

Inherits:
Object
  • Object
show all
Defined in:
ext/libxml/ruby_xml_dtd.c,
ext/libxml/ruby_xml_dtd.c

Overview

The XML::Dtd class is used to prepare DTD’s for validation of xml documents.

DTDs can be created from a string or a pair of public and system identifiers. Once a Dtd object is instantiated, an XML document can be validated by the XML::Document#validate method providing the XML::Dtd object as parameeter. The method will raise an exception if the document is not valid.

Basic usage:

# parse DTD
dtd = XML::Dtd.new(<<EOF)
<!ELEMENT root (item*) >
<!ELEMENT item (#PCDATA) >
EOF

# parse xml document to be validated
instance = XML::Document.file('instance.xml')

# validate
instance.validate(dtd)

Instance Method Summary collapse

Constructor Details

#XML::Dtd.new(dtd_string) ⇒ Object #XML::Dtd.new(external_id, system_id) ⇒ Object #XML::Dtd.new(external_id, system_id, name, document, internal) ⇒ Object

Create a new Dtd from the specified public and system identifiers:

* The first usage creates a DTD from a string and requires 1 parameter.
* The second usage loads and parses an external DTD and requires 2 parameters.
* The third usage creates a new internal or external DTD and requires 2 parameters and 3 optional parameters.
  The DTD is then attached to the specified document if it is not nil.

Parameters:

dtd_string - A string that contains a complete DTD
external_id - A string that specifies the DTD's external name. For example, "-//W3C//DTD XHTML 1.0 Transitional//EN"
system_id - A string that specififies the DTD's system name. For example, "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
name - A string that specifies the DTD's name. For example "xhtml1".
document - A xml document.
internal - Boolean value indicating whether this is an internal or external DTD. Optional. If not specified
           then external is assumed.


169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'ext/libxml/ruby_xml_dtd.c', line 169

static VALUE rxml_dtd_initialize(int argc, VALUE *argv, VALUE self)
{
  xmlDtdPtr xdtd;
  VALUE external, system;

  switch (argc)
  {
      case 3:
      case 4:
      case 5:
      {
          const xmlChar *xname = NULL, *xpublic = NULL, *xsystem = NULL;
          xmlDocPtr xdoc = NULL;

          VALUE name, doc, internal;
          rb_scan_args(argc, argv, "23", &external, &system, &name, &doc, &internal);

          if (external != Qnil)
          {
            Check_Type(external, T_STRING);
            xpublic = (const xmlChar*) StringValuePtr(external);
          }

          if (system != Qnil)
          {
            Check_Type(system, T_STRING);
            xsystem = (const xmlChar*) StringValuePtr(system);
          }

          if (name != Qnil)
          {
            Check_Type(name, T_STRING);
            xname = (const xmlChar*)StringValuePtr(name);
          }

          if (doc != Qnil)
          {
            if (rb_obj_is_kind_of(doc, cXMLDocument) == Qfalse)
              rb_raise(rb_eTypeError, "Must pass an LibXML::XML::Document object");
            TypedData_Get_Struct(doc, xmlDoc, &rxml_document_data_type, xdoc);
          }

          if (internal == Qnil || internal == Qfalse)
            xdtd = xmlNewDtd(xdoc, xname, xpublic, xsystem);
          else
            xdtd = xmlCreateIntSubset(xdoc, xname, xpublic, xsystem);

          if (xdtd == NULL)
            rxml_raise(xmlGetLastError());

          /* The document will free the dtd so Ruby should not */
          {
            VALUE *type_ptr = (VALUE *)&RTYPEDDATA(self)->type;
            *type_ptr = (*type_ptr & TYPED_DATA_EMBEDDED) | (VALUE)&rxml_dtd_data_type;
          }
          RTYPEDDATA_DATA(self) = xdtd;

          xmlSetTreeDoc((xmlNodePtr) xdtd, xdoc);
        }
        break;

      case 2:
      {
        rb_scan_args(argc, argv, "20", &external, &system);

        Check_Type(external, T_STRING);
        Check_Type(system, T_STRING);

        xdtd = xmlParseDTD((xmlChar*) StringValuePtr(external), (xmlChar*) StringValuePtr(system));

        if (xdtd == NULL)
          rxml_raise(xmlGetLastError());

        RTYPEDDATA_DATA(self) = xdtd;

        xmlSetTreeDoc((xmlNodePtr) xdtd, NULL);
        break;
      }
      case 1:
      {
        VALUE dtd_string;
        rb_scan_args(argc, argv, "10", &dtd_string);
        Check_Type(dtd_string, T_STRING);

        /* Note that buffer is freed by xmlParserInputBufferPush*/
        xmlCharEncoding enc = XML_CHAR_ENCODING_NONE;
        xmlParserInputBufferPtr buffer = xmlAllocParserInputBuffer(enc);
        xmlChar *new_string = xmlStrdup((xmlChar*) StringValuePtr(dtd_string));
        xmlParserInputBufferPush(buffer, xmlStrlen(new_string),
            (const char*) new_string);

        xdtd = xmlIOParseDTD(NULL, buffer, enc);

        if (xdtd == NULL)
          rxml_raise(xmlGetLastError());

        xmlFree(new_string);

        RTYPEDDATA_DATA(self) = xdtd;
        break;
      }
      default:
        rb_raise(rb_eArgError, "wrong number of arguments");
  }

  return self;
}

Instance Method Details

#external_idObject

Obtain this dtd’s external identifer (for a PUBLIC DTD).



85
86
87
88
89
90
91
92
93
94
95
# File 'ext/libxml/ruby_xml_dtd.c', line 85

static VALUE rxml_dtd_external_id_get(VALUE self)
{
  xmlDtdPtr xdtd;
  TypedData_Get_Struct(self, xmlDtd, &rxml_dtd_data_type, xdtd);


  if (xdtd->ExternalID == NULL)
    return (Qnil);
  else
    return (rxml_new_cstr( xdtd->ExternalID, NULL));
}

#nameObject

Obtain this dtd’s name.



103
104
105
106
107
108
109
110
111
112
113
# File 'ext/libxml/ruby_xml_dtd.c', line 103

static VALUE rxml_dtd_name_get(VALUE self)
{
  xmlDtdPtr xdtd;
  TypedData_Get_Struct(self, xmlDtd, &rxml_dtd_data_type, xdtd);


  if (xdtd->name == NULL)
    return (Qnil);
  else
    return (rxml_new_cstr( xdtd->name, NULL));
}

#typeNumeric

Obtain this node’s type identifier.

Returns:

  • (Numeric)


139
140
141
142
143
144
# File 'ext/libxml/ruby_xml_dtd.c', line 139

static VALUE rxml_dtd_type(VALUE self)
{
  xmlDtdPtr xdtd;
  TypedData_Get_Struct(self, xmlDtd, &rxml_dtd_data_type, xdtd);
  return (INT2NUM(xdtd->type));
}

#uriObject Also known as: system_id

Obtain this dtd’s URI (for a SYSTEM or PUBLIC DTD).



122
123
124
125
126
127
128
129
130
131
# File 'ext/libxml/ruby_xml_dtd.c', line 122

static VALUE rxml_dtd_uri_get(VALUE self)
{
  xmlDtdPtr xdtd;
  TypedData_Get_Struct(self, xmlDtd, &rxml_dtd_data_type, xdtd);

  if (xdtd->SystemID == NULL)
    return (Qnil);
  else
    return (rxml_new_cstr( xdtd->SystemID, NULL));
}