Class: LibXML::XML::Node

Inherits:
Object
  • Object
show all
Includes:
Enumerable
Defined in:
ext/libxml/ruby_xml_node.c,
lib/libxml/node.rb,
ext/libxml/ruby_xml_node.c

Overview

Nodes are the primary objects that make up an XML document. The node class represents most node types that are found in an XML document (but not LibXML::XML::Attributes, see LibXML::XML::Attr). It exposes libxml’s full API for creating, querying moving and deleting node objects. Many of these methods are documented in the DOM Level 3 specification found at: www.w3.org/TR/DOM-Level-3-Core/.

Constant Summary collapse

SPACE_DEFAULT =
INT2NUM(0)
SPACE_PRESERVE =
INT2NUM(1)
SPACE_NOT_INHERIT =
INT2NUM(-1)
INT2NUM(1)
INT2NUM(0)
INT2NUM(2)
INT2NUM(2)
INT2NUM(1)
INT2NUM(0)
INT2NUM(3)
INT2NUM(2)
INT2NUM(3)
INT2NUM(0)
INT2NUM(1)
ELEMENT_NODE =
INT2FIX(XML_ELEMENT_NODE)
ATTRIBUTE_NODE =
INT2FIX(XML_ATTRIBUTE_NODE)
TEXT_NODE =
INT2FIX(XML_TEXT_NODE)
CDATA_SECTION_NODE =
INT2FIX(XML_CDATA_SECTION_NODE)
ENTITY_REF_NODE =
INT2FIX(XML_ENTITY_REF_NODE)
ENTITY_NODE =
INT2FIX(XML_ENTITY_NODE)
PI_NODE =
INT2FIX(XML_PI_NODE)
COMMENT_NODE =
INT2FIX(XML_COMMENT_NODE)
DOCUMENT_NODE =
INT2FIX(XML_DOCUMENT_NODE)
DOCUMENT_TYPE_NODE =
INT2FIX(XML_DOCUMENT_TYPE_NODE)
DOCUMENT_FRAG_NODE =
INT2FIX(XML_DOCUMENT_FRAG_NODE)
NOTATION_NODE =
INT2FIX(XML_NOTATION_NODE)
HTML_DOCUMENT_NODE =
INT2FIX(XML_HTML_DOCUMENT_NODE)
DTD_NODE =
INT2FIX(XML_DTD_NODE)
ELEMENT_DECL =
INT2FIX(XML_ELEMENT_DECL)
ATTRIBUTE_DECL =
INT2FIX(XML_ATTRIBUTE_DECL)
ENTITY_DECL =
INT2FIX(XML_ENTITY_DECL)
NAMESPACE_DECL =
INT2FIX(XML_NAMESPACE_DECL)
XINCLUDE_START =
INT2FIX(XML_XINCLUDE_START)
XINCLUDE_END =
INT2FIX(XML_XINCLUDE_END)
DOCB_DOCUMENT_NODE =
Qnil

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#XML::Node.initialize(name, content = nil, namespace = nil) ⇒ XML::Node

Creates a new element with the specified name, content and namespace. The content and namespace may be nil.



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'ext/libxml/ruby_xml_node.c', line 312

static VALUE rxml_node_initialize(int argc, VALUE *argv, VALUE self)
{
  VALUE name;
  VALUE content;
  VALUE ns;
  xmlNodePtr xnode = NULL;
  xmlNsPtr xns = NULL;

  rb_scan_args(argc, argv, "12", &name, &content, &ns);

  name = rb_obj_as_string(name);

  if (!NIL_P(ns))
    TypedData_Get_Struct(ns, xmlNs, &rxml_namespace_type, xns);

  xnode = xmlNewNode(xns, (xmlChar*) StringValuePtr(name));

  if (xnode == NULL)
    rxml_raise(xmlGetLastError());

  // Link the ruby wrapper to the underlying libxml node
  RTYPEDDATA_DATA(self) = xnode;

  // Ruby is in charge of managing this node's memory
  rxml_node_manage(xnode, self);

  if (!NIL_P(content))
    rxml_node_content_set(self, content);

  return self;
}

Class Method Details

.XML::Node.new_cdata(content = nil) ⇒ XML::Node

Create a new #CDATA node, optionally setting the node’s content.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'ext/libxml/ruby_xml_node.c', line 191

static VALUE rxml_node_new_cdata(int argc, VALUE *argv, VALUE klass)
{
  VALUE content = Qnil;
  xmlNodePtr xnode;

  rb_scan_args(argc, argv, "01", &content);

  if (NIL_P(content))
  {
    xnode = xmlNewCDataBlock(NULL, NULL, 0);
  }
  else
  {
    content = rb_obj_as_string(content);
    xnode = xmlNewCDataBlock(NULL, (xmlChar*) StringValuePtr(content), (int)RSTRING_LEN(content));
  }

  if (xnode == NULL)
    rxml_raise(xmlGetLastError());

  return rxml_node_wrap(xnode);
}

.XML::Node.new_comment(content = nil) ⇒ XML::Node

Create a new comment node, optionally setting the node’s content.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'ext/libxml/ruby_xml_node.c', line 222

static VALUE rxml_node_new_comment(int argc, VALUE *argv, VALUE klass)
{
  VALUE content = Qnil;
  xmlNodePtr xnode;

  rb_scan_args(argc, argv, "01", &content);

  if (NIL_P(content))
  {
    xnode = xmlNewComment(NULL);
  }
  else
  {
    content = rb_obj_as_string(content);
    xnode = xmlNewComment((xmlChar*) StringValueCStr(content));
  }

  if (xnode == NULL)
    rxml_raise(xmlGetLastError());

  return rxml_node_wrap(xnode);
}

.XML::Node.new_pi(name, content = nil) ⇒ XML::Node

Create a new pi node, optionally setting the node’s content.



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'ext/libxml/ruby_xml_node.c', line 253

static VALUE rxml_node_new_pi(int argc, VALUE *argv, VALUE klass)
{
  VALUE name = Qnil;
  VALUE content = Qnil;
  xmlNodePtr xnode;

  rb_scan_args(argc, argv, "11", &name, &content);

  if (NIL_P(name))
  {
    rb_raise(rb_eRuntimeError, "You must provide me with a name for a PI.");
  }
  name = rb_obj_as_string(name);
  if (NIL_P(content))
  {
    xnode = xmlNewPI((xmlChar*) StringValuePtr(name), NULL);
  }
  else
  {
    content = rb_obj_as_string(content);
    xnode = xmlNewPI((xmlChar*) StringValuePtr(name), (xmlChar*) StringValueCStr(content));
  }

  if (xnode == NULL)
    rxml_raise(xmlGetLastError());

  return rxml_node_wrap(xnode);
}

.XML::Node.new_text(content) ⇒ XML::Node

Create a new text node.



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'ext/libxml/ruby_xml_node.c', line 289

static VALUE rxml_node_new_text(VALUE klass, VALUE content)
{
  xmlNodePtr xnode;
  Check_Type(content, T_STRING);
  content = rb_obj_as_string(content);

  xnode = xmlNewText((xmlChar*) StringValueCStr(content));

  if (xnode == NULL)
    rxml_raise(xmlGetLastError());

  return rxml_node_wrap(xnode);
}

Instance Method Details

#<<("Some text") ⇒ Object #<<(node) ⇒ Object

Add the specified text or XML::Node as a new child node to the current node.

If the specified argument is a string, it should be a raw string that contains unescaped XML special characters. Entity references are not supported.

The method will return the current node.



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'ext/libxml/ruby_xml_node.c', line 519

static VALUE rxml_node_content_add(VALUE self, VALUE obj)
{
  xmlNodePtr xnode;
  VALUE str;

  xnode = rxml_get_xnode(self);

  /* XXX This should only be legal for a CDATA type node, I think,
   * resulting in a merge of content, as if a string were passed
   * danj 070827
   */
  if (rb_obj_is_kind_of(obj, cXMLNode))
  { 
    rxml_node_modify_dom(self, obj, xmlAddChild);
  }
  else
  {
    str = rb_obj_as_string(obj);
    if (NIL_P(str) || TYPE(str) != T_STRING)
      rb_raise(rb_eTypeError, "invalid argument: must be string or XML::Node");

    xmlNodeAddContent(xnode, (xmlChar*) StringValuePtr(str));
  }
  return self;
}

#property("name") ⇒ Object #[]("name") ⇒ Object

Obtain the named property.



1114
1115
1116
1117
1118
# File 'ext/libxml/ruby_xml_node.c', line 1114

static VALUE rxml_node_attribute_get(VALUE self, VALUE name)
{
  VALUE attributes = rxml_node_attributes_get(self);
  return rxml_attributes_attribute_get(attributes, name);
}

#[]=("name") ⇒ Object

Set the named property.



1126
1127
1128
1129
1130
# File 'ext/libxml/ruby_xml_node.c', line 1126

static VALUE rxml_node_property_set(VALUE self, VALUE name, VALUE value)
{
  VALUE attributes = rxml_node_attributes_get(self);
  return rxml_attributes_attribute_set(attributes, name, value);
}

#attribute?Boolean

Specifies if this is an attribute node



207
208
209
# File 'lib/libxml/node.rb', line 207

def attribute?
  node_type == ATTRIBUTE_NODE
end

#attribute_decl?Boolean

Specifies if this is an attribute declaration node



212
213
214
# File 'lib/libxml/node.rb', line 212

def attribute_decl?
  node_type == ATTRIBUTE_DECL
end

#attributesObject

Returns the XML::Attributes for this node.



1099
1100
1101
1102
1103
1104
1105
# File 'ext/libxml/ruby_xml_node.c', line 1099

static VALUE rxml_node_attributes_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);
  return rxml_attributes_new(xnode);
}

#attributes?Boolean

Determines whether this node has attributes



9
10
11
# File 'lib/libxml/node.rb', line 9

def attributes?
  attributes.length > 0
end

#base_uriObject

Obtain this node’s base URI.



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'ext/libxml/ruby_xml_node.c', line 382

static VALUE rxml_node_base_uri_get(VALUE self)
{
  xmlNodePtr xnode;
  xmlChar* base_uri;
  VALUE result = Qnil;

  xnode = rxml_get_xnode(self);

  if (xnode->doc == NULL)
    return (result);

  base_uri = xmlNodeGetBase(xnode->doc, xnode);
  if (base_uri)
  {
    result = rxml_new_cstr( base_uri, NULL);
    xmlFree(base_uri);
  }

  return (result);
}

#base_uri=(uri) ⇒ Object

Set this node’s base URI.



411
412
413
414
415
416
417
418
419
420
421
422
# File 'ext/libxml/ruby_xml_node.c', line 411

static VALUE rxml_node_base_uri_set(VALUE self, VALUE uri)
{
  xmlNodePtr xnode;

  Check_Type(uri, T_STRING);
  xnode = rxml_get_xnode(self);
  if (xnode->doc == NULL)
    return (Qnil);

  xmlNodeSetBase(xnode, (xmlChar*) StringValuePtr(uri));
  return (Qtrue);
}

#empty?Boolean

Determine whether this node is an empty or whitespace only text-node.



703
704
705
706
707
708
709
710
711
# File 'ext/libxml/ruby_xml_node.c', line 703

static VALUE rxml_node_empty_q(VALUE self)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);
  if (xnode == NULL)
    return (Qnil);

  return ((xmlIsBlankNode(xnode) == 1) ? Qtrue : Qfalse);
}

#cdata?Boolean

Specifies if this is an CDATA node



217
218
219
# File 'lib/libxml/node.rb', line 217

def cdata?
  node_type == CDATA_SECTION_NODE
end

#childrenObject

Returns this node’s children as an array.



131
132
133
# File 'lib/libxml/node.rb', line 131

def children
  entries
end

#cloneObject

Create a shallow copy of the node. To create a deep copy call Node#copy(true)



15
16
17
# File 'lib/libxml/node.rb', line 15

def clone
  copy(false)
end

#comment?Boolean

Specifies if this is an comment node



222
223
224
# File 'lib/libxml/node.rb', line 222

def comment?
  node_type == COMMENT_NODE
end

#contentObject

Obtain this node’s content as a string.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'ext/libxml/ruby_xml_node.c', line 430

static VALUE rxml_node_content_get(VALUE self)
{
  xmlNodePtr xnode;
  xmlChar *content;
  VALUE result = Qnil;

  xnode = rxml_get_xnode(self);
  content = xmlNodeGetContent(xnode);
  if (content)
  {
    result = rxml_new_cstr(content, NULL);
    xmlFree(content);
  }

  return result;
}

#content=(content) ⇒ Object

Set this node’s content to the specified string.



453
454
455
456
457
458
459
460
461
462
463
464
# File 'ext/libxml/ruby_xml_node.c', line 453

static VALUE rxml_node_content_set(VALUE self, VALUE content)
{
  xmlNodePtr xnode;
  xmlChar* encoded_content;

  Check_Type(content, T_STRING);
  xnode = rxml_get_xnode(self);
  encoded_content = xmlEncodeSpecialChars(xnode->doc, (xmlChar*) StringValuePtr(content));
  xmlNodeSetContent(xnode, encoded_content);
  xmlFree(encoded_content);
  return (Qtrue);
}

#context(nslist = nil) ⇒ Object

call-seq:

node.context(namespaces=nil) -> XPath::Context

Returns a new XML::XPathContext for the current node.

Namespaces is an optional array of XML::NS objects



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/libxml/node.rb', line 53

def context(nslist = nil)
  if not self.doc
    raise(TypeError, "A node must belong to a document before a xpath context can be created")
  end

  context = XPath::Context.new(self.doc)
  context.node = self
  context.register_namespaces_from_node(self)
  context.register_namespaces_from_node(self.doc.root)
  context.register_namespaces(nslist) if nslist
  context
end

#copyXML::Node

Creates a copy of this node. To create a shallow copy set the deep parameter to false. To create a deep copy set the deep parameter to true.



1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'ext/libxml/ruby_xml_node.c', line 1316

static VALUE rxml_node_copy(VALUE self, VALUE deep)
{
  xmlNodePtr xnode;
  xmlNodePtr xcopy;
  int recursive = (deep == Qnil || deep == Qfalse) ? 0 : 1;
  xnode = rxml_get_xnode(self);

  xcopy = xmlCopyNode(xnode, recursive);

  if (xcopy)
    return rxml_node_wrap(xcopy);
  else
    return Qnil;
}

#debugObject

Print libxml debugging information to stdout. Requires that libxml was compiled with debugging enabled.



473
474
475
476
477
478
479
480
481
482
483
484
# File 'ext/libxml/ruby_xml_node.c', line 473

static VALUE rxml_node_debug(VALUE self)
{
#ifdef LIBXML_DEBUG_ENABLED
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);
  xmlDebugDumpNode(NULL, xnode, 2);
  return Qtrue;
#else
  rb_warn("libxml was compiled without debugging support.");
  return Qfalse;
#endif
}

#docObject

Obtain the XML::Document this node belongs to.



551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
# File 'ext/libxml/ruby_xml_node.c', line 551

static VALUE rxml_node_doc(VALUE self)
{
  xmlDocPtr xdoc = NULL;
  xmlNodePtr xnode = rxml_get_xnode(self);

  switch (xnode->type)
  {
  case XML_DOCUMENT_NODE:
#ifdef LIBXML_DOCB_ENABLED
  case XML_DOCB_DOCUMENT_NODE:
#endif
  case XML_HTML_DOCUMENT_NODE:
  case XML_NAMESPACE_DECL:
    break;
  case XML_ATTRIBUTE_NODE:
    xdoc = (xmlDocPtr)((xmlAttrPtr) xnode->doc);
    break;
  default:
    xdoc = xnode->doc;
  }

  if (xdoc == NULL)
    return (Qnil);

  return rxml_registry_lookup(xdoc);
}

#docbook_doc?Boolean

Specifies if this is an docbook node



227
228
229
# File 'lib/libxml/node.rb', line 227

def docbook_doc?
  node_type == DOCB_DOCUMENT_NODE
end

#doctype?Boolean

Specifies if this is an doctype node



232
233
234
# File 'lib/libxml/node.rb', line 232

def doctype?
  node_type == DOCUMENT_TYPE_NODE
end

#document?Boolean

Specifies if this is an document node



237
238
239
# File 'lib/libxml/node.rb', line 237

def document?
  node_type == DOCUMENT_NODE
end

#dtd?Boolean

Specifies if this is an DTD node



242
243
244
# File 'lib/libxml/node.rb', line 242

def dtd?
  node_type == DTD_NODE
end

#dupObject

:call-seq:

node.dup -> XML::Node

Create a shallow copy of the node. To create a deep copy call Node#copy(true)



43
44
45
# File 'lib/libxml/node.rb', line 43

def dup
  copy(false)
end

#eachXML::Node Also known as: each_child

Iterates over this node’s children, including text nodes, element nodes, etc. If you wish to iterate only over child elements, use XML::Node#each_element.

doc = XML::Document.new('model/books.xml')
doc.root.each {|node| puts node}


677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'ext/libxml/ruby_xml_node.c', line 677

static VALUE rxml_node_each(VALUE self)
{
  xmlNodePtr xnode;
  xmlNodePtr xcurrent;
  xnode = rxml_get_xnode(self);

  xcurrent = xnode->children;

  while (xcurrent)
  {
    /* The user could remove this node, so first stache
       away the next node. */
    xmlNodePtr xnext = xcurrent->next;

    rb_yield(rxml_node_wrap(xcurrent));
    xcurrent = xnext;
  }
  return Qnil;
}

#each_attrObject

——- Traversal —————- Iterates over this node’s attributes.

doc = XML::Document.new('model/books.xml')
doc.root.each_attr {|attr| puts attr}


103
104
105
106
107
# File 'lib/libxml/node.rb', line 103

def each_attr
  attributes.each do |attr|
    yield(attr)
  end
end

#each_elementObject

Iterates over this node’s child elements (nodes that have a node_type == ELEMENT_NODE).

doc = XML::Document.new('model/books.xml')
doc.root.each_element {|element| puts element}


114
115
116
117
118
# File 'lib/libxml/node.rb', line 114

def each_element
  each do |node|
    yield(node) if node.node_type == ELEMENT_NODE
  end
end

#element?Boolean

Specifies if this is an element node



247
248
249
# File 'lib/libxml/node.rb', line 247

def element?
  node_type == ELEMENT_NODE
end

#element_decl?Boolean

Specifies if this is an element declaration node



257
258
259
# File 'lib/libxml/node.rb', line 257

def element_decl?
  node_type == ELEMENT_DECL
end

#empty?Boolean

Determine whether this node is an empty or whitespace only text-node.



703
704
705
706
707
708
709
710
711
# File 'ext/libxml/ruby_xml_node.c', line 703

static VALUE rxml_node_empty_q(VALUE self)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);
  if (xnode == NULL)
    return (Qnil);

  return ((xmlIsBlankNode(xnode) == 1) ? Qtrue : Qfalse);
}

#entity?Boolean

Specifies if this is an entity node



252
253
254
# File 'lib/libxml/node.rb', line 252

def entity?
  node_type == ENTITY_NODE
end

#entity_ref?Boolean

Specifies if this is an entity reference node



262
263
264
# File 'lib/libxml/node.rb', line 262

def entity_ref?
  node_type == ENTITY_REF_NODE
end

#eql?(other_node) ⇒ Boolean Also known as: ==

Test equality between the two nodes. Two nodes are equal if they are the same node.



720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
# File 'ext/libxml/ruby_xml_node.c', line 720

static VALUE rxml_node_eql_q(VALUE self, VALUE other)
{
  if (self == other)
  {
    return Qtrue;
  }
  else if (NIL_P(other))
  {
    return Qfalse;
  }
  else
  {
    xmlNodePtr xnode = rxml_get_xnode(self);
    xmlNodePtr xnode_other = rxml_get_xnode(other);
    return xnode == xnode_other ? Qtrue : Qfalse;
  }
}

#find(xpath, nslist = nil) ⇒ Object

call-seq:

node.find(namespaces=nil) -> XPath::XPathObject

Return nodes matching the specified xpath expression. For more information, please refer to the documentation for XML::Document#find.

Namespaces is an optional array of XML::NS objects



74
75
76
# File 'lib/libxml/node.rb', line 74

def find(xpath, nslist = nil)
  self.context(nslist).find(xpath)
end

#find_first(xpath, nslist = nil) ⇒ Object

call-seq:

node.find_first(namespaces=nil) -> XML::Node

Return the first node matching the specified xpath expression. For more information, please refer to the documentation for the #find method.



84
85
86
# File 'lib/libxml/node.rb', line 84

def find_first(xpath, nslist = nil)
  find(xpath, nslist).first
end

#firstXML::Node Also known as: child

Returns this node’s first child node if any.



492
493
494
495
496
497
498
499
500
501
502
# File 'ext/libxml/ruby_xml_node.c', line 492

static VALUE rxml_node_first_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);

  if (xnode->children)
    return (rxml_node_wrap(xnode->children));
  else
    return (Qnil);
}

#first?Boolean Also known as: child?, children?

Determines whether this node has a first node



126
127
128
# File 'lib/libxml/node.rb', line 126

def first?
  not first.nil?
end

#fragment?Boolean

Specifies if this is a fragment node



267
268
269
# File 'lib/libxml/node.rb', line 267

def fragment?
  node_type == DOCUMENT_FRAG_NODE
end

#html_doc?Boolean

Specifies if this is a html document node



272
273
274
# File 'lib/libxml/node.rb', line 272

def html_doc?
  node_type == HTML_DOCUMENT_NODE
end

#inner_xml(options = Hash.new) ⇒ Object

call-seq:

node.inner_xml -> "string"
node.inner_xml(:indent => true, :encoding => 'UTF-8', :level => 0) -> "string"

Converts a node’s children to a string representation. To include the node, use XML::Node#to_s. For more information about the supported options, see XML::Node#to_s.



26
27
28
29
30
31
32
33
34
35
36
# File 'lib/libxml/node.rb', line 26

def inner_xml(options = Hash.new)
  io = nil
  self.each do |node|
    xml = node.to_s(options)
    # Create the string IO here since we now know the encoding
    io = create_string_io(xml) unless io
    io << xml
  end

  io ? io.string : nil
end

#langObject

Obtain the language set for this node, if any. This is set in XML via the xml:lang attribute.



745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
# File 'ext/libxml/ruby_xml_node.c', line 745

static VALUE rxml_node_lang_get(VALUE self)
{
  xmlNodePtr xnode;
  xmlChar *lang;
  VALUE result = Qnil;

  xnode = rxml_get_xnode(self);
  lang = xmlNodeGetLang(xnode);

  if (lang)
  {
    result = rxml_new_cstr( lang, NULL);
    xmlFree(lang);
  }

  return (result);
}

#lang=(lang) ⇒ Object

Set the language for this node. This affects the value of the xml:lang attribute.



772
773
774
775
776
777
778
779
780
781
# File 'ext/libxml/ruby_xml_node.c', line 772

static VALUE rxml_node_lang_set(VALUE self, VALUE lang)
{
  xmlNodePtr xnode;

  Check_Type(lang, T_STRING);
  xnode = rxml_get_xnode(self);
  xmlNodeSetLang(xnode, (xmlChar*) StringValuePtr(lang));

  return (Qtrue);
}

#lastXML::Node

Obtain the last child node of this node, if any.



789
790
791
792
793
794
795
796
797
798
799
# File 'ext/libxml/ruby_xml_node.c', line 789

static VALUE rxml_node_last_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);

  if (xnode->last)
    return (rxml_node_wrap(xnode->last));
  else
    return (Qnil);
}

#last?Boolean

Determines whether this node has a last node



146
147
148
# File 'lib/libxml/node.rb', line 146

def last?
  not last.nil?
end

#line_numNumeric

Obtain the line number (in the XML document) that this node was read from. If default_line_numbers is set false (the default), this method returns zero.



809
810
811
812
813
814
815
816
817
818
819
820
# File 'ext/libxml/ruby_xml_node.c', line 809

static VALUE rxml_node_line_num(VALUE self)
{
  xmlNodePtr xnode;
  long line_num;
  xnode = rxml_get_xnode(self);

  line_num = xmlGetLineNo(xnode);
  if (line_num == -1)
    return (Qnil);
  else
    return (LONG2NUM((long) line_num));
}

#nameObject

Obtain this node’s name.



901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'ext/libxml/ruby_xml_node.c', line 901

static VALUE rxml_node_name_get(VALUE self)
{
  xmlNodePtr xnode;
  const xmlChar *name;

  xnode = rxml_get_xnode(self);

  switch (xnode->type)
  {
  case XML_DOCUMENT_NODE:
#ifdef LIBXML_DOCB_ENABLED
    case XML_DOCB_DOCUMENT_NODE:
#endif
  case XML_HTML_DOCUMENT_NODE:
  {
    xmlDocPtr doc = (xmlDocPtr) xnode;
    name = doc->URL;
    break;
  }
  case XML_ATTRIBUTE_NODE:
  {
    xmlAttrPtr attr = (xmlAttrPtr) xnode;
    name = attr->name;
    break;
  }
  case XML_NAMESPACE_DECL:
  {
    xmlNsPtr ns = (xmlNsPtr) xnode;
    name = ns->prefix;
    break;
  }
  default:
    name = xnode->name;
    break;
  }

  if (xnode->name == NULL)
    return (Qnil);
  else
    return (rxml_new_cstr( name, NULL));
}

#name=(name) ⇒ Object

Set this node’s name.



949
950
951
952
953
954
955
956
957
958
959
960
961
962
# File 'ext/libxml/ruby_xml_node.c', line 949

static VALUE rxml_node_name_set(VALUE self, VALUE name)
{
  xmlNodePtr xnode;
  const xmlChar *xname;

  Check_Type(name, T_STRING);
  xnode = rxml_get_xnode(self);
  xname = (const xmlChar*)StringValuePtr(name);

	/* Note: calling xmlNodeSetName() for a text node is ignored by libXML. */
  xmlNodeSetName(xnode, xname);

  return (Qtrue);
}

#namespace?Boolean

Specifies if this is a namespace node (not if it has a namepsace)



278
279
280
# File 'lib/libxml/node.rb', line 278

def namespace?
  node_type == NAMESPACE_DECL
end

#namespacesObject

call-seq:

node.namespacess -> XML::Namespaces

Returns this node’s XML::Namespaces object, which is used to access the namespaces associated with this node.



94
95
96
# File 'lib/libxml/node.rb', line 94

def namespaces
  @namespaces ||= XML::Namespaces.new(self)
end

#nextXML::Node

Returns the next sibling node if one exists.



970
971
972
973
974
975
976
977
978
979
980
# File 'ext/libxml/ruby_xml_node.c', line 970

static VALUE rxml_node_next_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);

  if (xnode->next)
    return (rxml_node_wrap(xnode->next));
  else
    return (Qnil);
}

#next=(node) ⇒ Object

Adds the specified node as the next sibling of the current node. If the node already exists in the document, it is first removed from its existing context. Any adjacent text nodes will be merged together, meaning the returned node may be different than the original node.



992
993
994
995
# File 'ext/libxml/ruby_xml_node.c', line 992

static VALUE rxml_node_next_set(VALUE self, VALUE next)
{
  return rxml_node_modify_dom(self, next, xmlAddNextSibling);
}

#next?Boolean

Determines whether this node has a next node



136
137
138
# File 'lib/libxml/node.rb', line 136

def next?
  not self.next.nil?
end

#typeNumeric

Obtain this node’s type identifier.



1299
1300
1301
1302
1303
1304
# File 'ext/libxml/ruby_xml_node.c', line 1299

static VALUE rxml_node_type(VALUE self)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);
  return (INT2NUM(xnode->type));
}

#node_type_nameObject

Returns this node’s type name



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/libxml/node.rb', line 154

def node_type_name
  case node_type
    # Most common choices first
    when ATTRIBUTE_NODE
      'attribute'
    when DOCUMENT_NODE
      'document_xml'
    when ELEMENT_NODE
      'element'
    when TEXT_NODE
      'text'
    
    # Now the rest  
    when ATTRIBUTE_DECL
      'attribute_decl'
    when CDATA_SECTION_NODE
      'cdata'
    when COMMENT_NODE
      'comment'
    when DOCB_DOCUMENT_NODE
      'document_docbook'
    when DOCUMENT_FRAG_NODE
      'fragment'
    when DOCUMENT_TYPE_NODE
      'doctype'
    when DTD_NODE
      'dtd'
    when ELEMENT_DECL
      'elem_decl'
    when ENTITY_DECL
      'entity_decl'
    when ENTITY_NODE
      'entity'
    when ENTITY_REF_NODE
      'entity_ref'
    when HTML_DOCUMENT_NODE
      'document_html'
    when NAMESPACE_DECL
      'namespace'
    when NOTATION_NODE
      'notation'
    when PI_NODE
      'pi'
    when XINCLUDE_START
      'xinclude_start'
    when XINCLUDE_END
      'xinclude_end'
    else
      raise(UnknownType, "Unknown node type: %n", node.node_type);
  end
end

#notation?Boolean

Specifies if this is a notation node



283
284
285
# File 'lib/libxml/node.rb', line 283

def notation?
  node_type == NOTATION_NODE
end

#output_escaping=(true) ⇒ Object #output_escaping=(true) ⇒ Object #output_escaping=(true) ⇒ Object

Controls whether this text node or the immediate text node children of an element or attribute node escapes their output. Any other type of node will simply ignore this operation.

Text nodes which are added to an element or attribute node will be affected by any previous setting of this property.



1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
# File 'ext/libxml/ruby_xml_node.c', line 1234

static VALUE rxml_node_output_escaping_set(VALUE self, VALUE value)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);

  switch (xnode->type) {
  case XML_TEXT_NODE:
    xnode->name = (value != Qfalse && value != Qnil) ? xmlStringText : xmlStringTextNoenc;
    break;
  case XML_ELEMENT_NODE:
  case XML_ATTRIBUTE_NODE:
    {
      const xmlChar *name = (value != Qfalse && value != Qnil) ? xmlStringText : xmlStringTextNoenc;
      xmlNodePtr tmp;
      for (tmp = xnode->children; tmp; tmp = tmp->next)
        if (tmp->type == XML_TEXT_NODE)
          tmp->name = name;
    }
    break;
  default:
    return Qnil;
  }

  return (value!=Qfalse && value!=Qnil) ? Qtrue : Qfalse;
}

#output_escaping?Boolean #output_escaping?Boolean #output_escaping?Boolean #output_escaping?Boolean

Determine whether this node escapes it’s output or not.

Text nodes return only true or false. Element and attribute nodes examine their immediate text node children to determine the value. Any other type of node always returns nil.

If an element or attribute node has at least one immediate child text node and all the immediate text node children have the same output_escaping? value, that value is returned. Otherwise, nil is returned.



1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
# File 'ext/libxml/ruby_xml_node.c', line 1187

static VALUE rxml_node_output_escaping_q(VALUE self)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);

  switch (xnode->type) {
  case XML_TEXT_NODE:
    return xnode->name==xmlStringTextNoenc ? Qfalse : Qtrue;
  case XML_ELEMENT_NODE:
  case XML_ATTRIBUTE_NODE:
    {
      xmlNodePtr tmp = xnode->children;
      const xmlChar *match = NULL;

      /* Find the first text node and use it as the reference. */
      while (tmp && tmp->type != XML_TEXT_NODE)
        tmp = tmp->next;
      if (! tmp)
        return Qnil;
      match = tmp->name;

      /* Walk the remaining text nodes until we run out or one doesn't match. */
      while (tmp && (tmp->type != XML_TEXT_NODE || match == tmp->name))
        tmp = tmp->next;

      /* We're left with either the mismatched node or the aggregate result. */
      return tmp ? Qnil : (match==xmlStringTextNoenc ? Qfalse : Qtrue);
    }
    break;
  default:
    return Qnil;
  }
}

#parentXML::Node

Obtain this node’s parent node, if any.



1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
# File 'ext/libxml/ruby_xml_node.c', line 1003

static VALUE rxml_node_parent_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);

  if (xnode->parent)
    return (rxml_node_wrap(xnode->parent));
  else
    return (Qnil);
}

#parent?Boolean

Determines whether this node has a parent node



121
122
123
# File 'lib/libxml/node.rb', line 121

def parent?
  not parent.nil?
end

#pathObject

Obtain this node’s path.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
# File 'ext/libxml/ruby_xml_node.c', line 1021

static VALUE rxml_node_path(VALUE self)
{
  xmlNodePtr xnode;
  xmlChar *path;
  VALUE result = Qnil;

  xnode = rxml_get_xnode(self);
  path = xmlGetNodePath(xnode);

  if (path)
  {
    result = rxml_new_cstr( path, NULL);
    xmlFree(path);
  }

  return result;
}

#pi?Boolean

Specifies if this is a processiong instruction node



288
289
290
# File 'lib/libxml/node.rb', line 288

def pi?
  node_type == PI_NODE
end

#prevXML::Node

Obtain the previous sibling, if any.



1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
# File 'ext/libxml/ruby_xml_node.c', line 1045

static VALUE rxml_node_prev_get(VALUE self)
{
  xmlNodePtr xnode;
  xmlNodePtr node;
  xnode = rxml_get_xnode(self);

  switch (xnode->type)
  {
  case XML_DOCUMENT_NODE:
#ifdef LIBXML_DOCB_ENABLED
    case XML_DOCB_DOCUMENT_NODE:
#endif
  case XML_HTML_DOCUMENT_NODE:
  case XML_NAMESPACE_DECL:
    node = NULL;
    break;
  case XML_ATTRIBUTE_NODE:
  {
    xmlAttrPtr attr = (xmlAttrPtr) xnode;
    node = (xmlNodePtr) attr->prev;
  }
    break;
  default:
    node = xnode->prev;
    break;
  }

  if (node == NULL)
    return (Qnil);
  else
    return (rxml_node_wrap(node));
}

#prev=(node) ⇒ Object

Adds the specified node as the previous sibling of the current node. If the node already exists in the document, it is first removed from its existing context. Any adjacent text nodes will be merged together, meaning the returned node may be different than the original node.



1088
1089
1090
1091
# File 'ext/libxml/ruby_xml_node.c', line 1088

static VALUE rxml_node_prev_set(VALUE self, VALUE prev)
{
  return rxml_node_modify_dom(self, prev, xmlAddPrevSibling);
}

#prev?Boolean

Determines whether this node has a previous node



141
142
143
# File 'lib/libxml/node.rb', line 141

def prev?
  not prev.nil?
end

#remove!Object

Removes this node and its children from the document tree by setting its document, parent and siblings to nil. You can add the returned node back into a document. Otherwise, the node will be freed once any references to it go out of scope.



1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
# File 'ext/libxml/ruby_xml_node.c', line 1141

static VALUE rxml_node_remove_ex(VALUE self)
{
  xmlNodePtr xnode = rxml_get_xnode(self);
 
  // Now unlink the node from its parent
  xmlUnlinkNode(xnode);

  // Ruby now manages this node
  rxml_node_manage(xnode, self);

  // Now return the removed node so the user can do something with it
  return self;
}

#sibling=(node) ⇒ Object

Adds the specified node as the end of the current node’s list of siblings. If the node already exists in the document, it is first removed from its existing context. Any adjacent text nodes will be merged together, meaning the returned node may be different than the original node.



1165
1166
1167
1168
# File 'ext/libxml/ruby_xml_node.c', line 1165

static VALUE rxml_node_sibling_set(VALUE self, VALUE sibling)
{
  return rxml_node_modify_dom(self, sibling, xmlAddSibling);
}

#space_preserveObject

Determine whether this node preserves whitespace.



1266
1267
1268
1269
1270
1271
1272
# File 'ext/libxml/ruby_xml_node.c', line 1266

static VALUE rxml_node_space_preserve_get(VALUE self)
{
  xmlNodePtr xnode;

  xnode = rxml_get_xnode(self);
  return (INT2NUM(xmlNodeGetSpacePreserve(xnode)));
}

#space_preserve=(true) ⇒ Object

Control whether this node preserves whitespace.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'ext/libxml/ruby_xml_node.c', line 1280

static VALUE rxml_node_space_preserve_set(VALUE self, VALUE value)
{
  xmlNodePtr xnode;
  xnode = rxml_get_xnode(self);

  if (value == Qfalse)
    xmlNodeSetSpacePreserve(xnode, 0);
  else
    xmlNodeSetSpacePreserve(xnode, 1);

  return (Qnil);
}

#text?Boolean

Specifies if this is a text node



293
294
295
# File 'lib/libxml/node.rb', line 293

def text?
  node_type == TEXT_NODE
end

#to_sObject #to_s(: indent) ⇒ true

Converts a node, and all of its children, to a string representation. To include only the node’s children, use the the XML::Node#inner_xml method.

You may provide an optional hash table to control how the string is generated. Valid options are:

:indent - Specifies if the string should be indented. The default value is true. Note that indentation is only added if both :indent is true and XML.indent_tree_output is true. If :indent is set to false, then both indentation and line feeds are removed from the result.

:level - Specifies the indentation level. The amount of indentation is equal to the (level * number_spaces) + number_spaces, where libxml defaults the number of spaces to 2. Thus a level of 0 results in 2 spaces, level 1 results in 4 spaces, level 2 results in 6 spaces, etc.

:encoding - Specifies the output encoding of the string. It defaults to XML::Encoding::UTF8. To change it, use one of the XML::Encoding encoding constants.



604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
# File 'ext/libxml/ruby_xml_node.c', line 604

static VALUE rxml_node_to_s(int argc, VALUE *argv, VALUE self)
{
  VALUE result = Qnil;
  VALUE options = Qnil;
  xmlNodePtr xnode;
  xmlCharEncodingHandlerPtr encodingHandler;
  xmlOutputBufferPtr output;

  int level = 0;
  int indent = 1;
  const xmlChar *xencoding = (const xmlChar*)"UTF-8";

  rb_scan_args(argc, argv, "01", &options);

  if (!NIL_P(options))
  {
    VALUE rencoding, rindent, rlevel;
    Check_Type(options, T_HASH);
    rencoding = rb_hash_aref(options, ID2SYM(rb_intern("encoding")));
    rindent = rb_hash_aref(options, ID2SYM(rb_intern("indent")));
    rlevel = rb_hash_aref(options, ID2SYM(rb_intern("level")));

    if (rindent == Qfalse)
      indent = 0;

    if (rlevel != Qnil)
      level = NUM2INT(rlevel);

    if (rencoding != Qnil)
    {
      xencoding = (const xmlChar*)xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
      if (!xencoding)
        rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
    }
  }

  encodingHandler = xmlFindCharEncodingHandler((const char*)xencoding);
  output = xmlAllocOutputBuffer(encodingHandler);

  xnode = rxml_get_xnode(self);

  xmlNodeDumpOutput(output, xnode->doc, xnode, level, indent, (const char*)xencoding);
  xmlOutputBufferFlush(output);

#ifdef LIBXML2_NEW_BUFFER
  if (output->conv)
    result = rxml_new_cstr(xmlBufContent(output->conv), xencoding);
  else
    result = rxml_new_cstr(xmlBufContent(output->buffer), xencoding);
#else
  if (output->conv)
    result = rxml_new_cstr(xmlBufferContent(output->conv), xencoding);
  else
    result = rxml_new_cstr(xmlBufferContent(output->buffer), xencoding);
#endif

  xmlOutputBufferClose(output);
  
  return result;
}

#xinclude_end?Boolean

Specifies if this is an xinclude end node



298
299
300
# File 'lib/libxml/node.rb', line 298

def xinclude_end?
  node_type == XINCLUDE_END
end

#xinclude_start?Boolean

Specifies if this is an xinclude start node



303
304
305
# File 'lib/libxml/node.rb', line 303

def xinclude_start?
  node_type == XINCLUDE_START
end

#xlink?Boolean

Determine whether this node is an xlink node.



828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'ext/libxml/ruby_xml_node.c', line 828

static VALUE rxml_node_xlink_q(VALUE self)
{
  xmlNodePtr xnode;
  xlinkType xlt;

  xnode = rxml_get_xnode(self);
  xlt = xlinkIsLink(xnode->doc, xnode);

  if (xlt == XLINK_TYPE_NONE)
    return (Qfalse);
  else
    return (Qtrue);
}

Obtain the type identifier for this xlink, if applicable. If this is not an xlink node (see xlink?), will return nil.



850
851
852
853
854
855
856
857
858
859
860
861
862
# File 'ext/libxml/ruby_xml_node.c', line 850

static VALUE rxml_node_xlink_type(VALUE self)
{
  xmlNodePtr xnode;
  xlinkType xlt;

  xnode = rxml_get_xnode(self);
  xlt = xlinkIsLink(xnode->doc, xnode);

  if (xlt == XLINK_TYPE_NONE)
    return (Qnil);
  else
    return (INT2NUM(xlt));
}

Obtain the type name for this xlink, if applicable. If this is not an xlink node (see xlink?), will return nil.



872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
# File 'ext/libxml/ruby_xml_node.c', line 872

static VALUE rxml_node_xlink_type_name(VALUE self)
{
  xmlNodePtr xnode;
  xlinkType xlt;

  xnode = rxml_get_xnode(self);
  xlt = xlinkIsLink(xnode->doc, xnode);

  switch (xlt)
  {
  case XLINK_TYPE_NONE:
    return (Qnil);
  case XLINK_TYPE_SIMPLE:
    return (rxml_new_cstr((const xmlChar*)"simple", NULL));
  case XLINK_TYPE_EXTENDED:
    return (rxml_new_cstr((const xmlChar*)"extended", NULL));
  case XLINK_TYPE_EXTENDED_SET:
    return (rxml_new_cstr((const xmlChar*)"extended_set", NULL));
  default:
    rb_fatal("Unknowng xlink type, %d", xlt);
  }
}