Class: LibXML::XML::Document
- Inherits:
-
Object
- Object
- LibXML::XML::Document
- Defined in:
- ext/libxml/ruby_xml_document.c,
lib/libxml/document.rb,
ext/libxml/ruby_xml_document.c
Overview
The XML::Document class provides a tree based API for working with xml documents. You may directly create a document and manipulate it, or create a document from a data source by using an XML::Parser object.
To read a document from a file:
doc = XML::Document.file('my_file')
To use a parser to read a document:
parser = XML::Parser.file('my_file')
doc = parser.parse
To create a document from scratch:
doc = XML::Document.new()
doc.root = XML::Node.new('root_node')
doc.root << XML::Node.new('elem1')
doc.save(filename, :indent => true, :encoding => 'UTF-8')
To write a document to a file:
doc = XML::Document.new()
doc.root = XML::Node.new('root_node')
root = doc.root
root << elem1 = XML::Node.new('elem1')
elem1['attr1'] = 'val1'
elem1['attr2'] = 'val2'
root << elem2 = XML::Node.new('elem2')
elem2['attr1'] = 'val1'
elem2['attr2'] = 'val2'
root << elem3 = XML::Node.new('elem3')
elem3 << elem4 = XML::Node.new('elem4')
elem3 << elem5 = XML::Node.new('elem5')
elem5 << elem6 = XML::Node.new('elem6')
elem6 << 'Content for element 6'
elem3['attr'] = 'baz'
doc.save(filename, :indent => true, :encoding => 'UTF-8')
Class Method Summary collapse
-
.document(value) ⇒ Object
call-seq: XML::Document.document(document) -> XML::Document.
-
.file(value, options = {}) ⇒ Object
call-seq: XML::Document.file(path) -> XML::Document XML::Document.file(path, :encoding => XML::Encoding::UTF_8, :options => XML::Parser::Options::NOENT) -> XML::Document.
-
.io(value, options = {}) ⇒ Object
call-seq: XML::Document.io(io) -> XML::Document XML::Document.io(io, :encoding => XML::Encoding::UTF_8, :options => XML::Parser::Options::NOENT :base_uri=“libxml.org”) -> XML::Document.
-
.string(value, options = {}) ⇒ Object
call-seq: XML::Document.string(string) XML::Document.string(string, :encoding => XML::Encoding::UTF_8, :options => XML::Parser::Options::NOENT :base_uri=“libxml.org”) -> XML::Document.
Instance Method Summary collapse
-
#child ⇒ Object
Get this document’s child node.
-
#child? ⇒ Boolean
Determine whether this document has a child node.
-
#compression ⇒ Numeric
Obtain this document’s compression mode identifier.
-
#compression=(num) ⇒ Object
Set this document’s compression mode.
-
#compression? ⇒ Boolean
Determine whether this document is compressed.
-
#context(nslist = nil) ⇒ Object
Returns a new XML::XPathContext for the document.
-
#debug ⇒ Object
Print libxml debugging information to stdout.
- #debug_dump ⇒ Object
- #debug_dump_head ⇒ Object
- #debug_format_dump ⇒ Object
-
#docbook_doc? ⇒ Boolean
Specifies if this is an docbook node.
-
#document? ⇒ Boolean
Specifies if this is an DOCTYPE node.
- #dump ⇒ Object
-
#encoding ⇒ XML::Encoding::UTF_8
Returns the LibXML encoding constant specified by this document.
-
#encoding=(XML) ⇒ Object
Set the encoding for this document.
-
#find(xpath, nslist = nil) ⇒ Object
Return the nodes matching the specified xpath expression, optionally using the specified namespace.
-
#find_first(xpath, nslist = nil) ⇒ Object
Return the first node matching the specified xpath expression.
- #format_dump ⇒ Object
-
#html_doc? ⇒ Boolean
Specifies if this is an html node.
-
#import(node) ⇒ XML::Node
Creates a copy of the node that can be inserted into the current document.
-
#XML::Document.initialize(xml_version = 1.0) ⇒ Object
constructor
Initializes a new XML::Document, optionally specifying the XML version.
-
#last ⇒ Object
Obtain the last node.
-
#last? ⇒ Boolean
Determine whether there is a last node.
-
#next ⇒ Object
Obtain the next node.
-
#next? ⇒ Boolean
Determine whether there is a next node.
-
#type ⇒ Numeric
Obtain this node’s type identifier.
-
#node_type_name ⇒ Object
Returns this node’s type name.
-
#order_elements! ⇒ Object
Call this routine to speed up XPath computation on static documents.
-
#parent ⇒ Object
Obtain the parent node.
-
#parent? ⇒ Boolean
Determine whether there is a parent node.
-
#prev ⇒ Object
Obtain the previous node.
-
#prev? ⇒ Boolean
Determine whether there is a previous node.
-
#rb_encoding ⇒ Encoding
Returns the Ruby encoding specified by this document (available on Ruby 1.9.x and higher).
- #reader ⇒ Object
-
#root ⇒ Object
Obtain the root node.
-
#root=(node) ⇒ Object
Set the root node.
-
#save(*args) ⇒ Object
Saves a document to a file.
-
#standalone? ⇒ Boolean
Determine whether this is a standalone document.
-
#to_s(*args) ⇒ Object
Converts a document, and all of its children, to a string representation.
-
#url ⇒ Object
Obtain this document’s source URL, if any.
-
#validate(dtd) ⇒ Object
Validate this document against the specified XML::DTD.
-
#validate_schema(relaxng) ⇒ Object
Validate this document against the specified XML::RelaxNG.
-
#validate_schema(schema) ⇒ Object
Validate this document against the specified XML::Schema.
-
#version ⇒ Object
Obtain the XML version specified by this document.
-
#xhtml? ⇒ Boolean
Determine whether this is an XHTML document.
-
#xinclude ⇒ Numeric
Process xinclude directives in this document.
Constructor Details
#XML::Document.initialize(xml_version = 1.0) ⇒ Object
Initializes a new XML::Document, optionally specifying the XML version.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'ext/libxml/ruby_xml_document.c', line 118
static VALUE rxml_document_initialize(int argc, VALUE *argv, VALUE self)
{
xmlDocPtr xdoc;
VALUE xmlver;
switch (argc)
{
case 0:
xmlver = rb_str_new2("1.0");
break;
case 1:
rb_scan_args(argc, argv, "01", &xmlver);
break;
default:
rb_raise(rb_eArgError, "wrong number of arguments (need 0 or 1)");
}
Check_Type(xmlver, T_STRING);
xdoc = xmlNewDoc((xmlChar*) StringValuePtr(xmlver));
xdoc->_private = (void*) self;
DATA_PTR(self) = xdoc;
return self;
}
|
Class Method Details
.document(value) ⇒ Object
call-seq:
XML::Document.document(document) -> XML::Document
Creates a new document based on the specified document.
Parameters:
document - A preparsed document.
14 15 16 |
# File 'lib/libxml/document.rb', line 14 def self.document(value) Parser.document(value).parse end |
.file(value, options = {}) ⇒ Object
call-seq:
XML::Document.file(path) -> XML::Document
XML::Document.file(path, :encoding => XML::Encoding::UTF_8,
:options => XML::Parser::Options::NOENT) -> XML::Document
Creates a new document from the specified file or uri.
You may provide an optional hash table to control how the parsing is performed. Valid options are:
encoding - The document encoding, defaults to nil. Valid values
are the encoding constants defined on XML::Encoding.
options - Parser options. Valid values are the constants defined on
XML::Parser::Options. Mutliple options can be combined
by using Bitwise OR (|).
33 34 35 |
# File 'lib/libxml/document.rb', line 33 def self.file(value, = {}) Parser.file(value, ).parse end |
.io(value, options = {}) ⇒ Object
call-seq:
XML::Document.io(io) -> XML::Document
XML::Document.io(io, :encoding => XML::Encoding::UTF_8,
:options => XML::Parser::Options::NOENT
:base_uri="http://libxml.org") -> XML::Document
Creates a new document from the specified io object.
Parameters:
io - io object that contains the xml to parser
base_uri - The base url for the parsed document.
encoding - The document encoding, defaults to nil. Valid values
are the encoding constants defined on XML::Encoding.
options - Parser options. Valid values are the constants defined on
XML::Parser::Options. Mutliple options can be combined
by using Bitwise OR (|).
54 55 56 |
# File 'lib/libxml/document.rb', line 54 def self.io(value, = {}) Parser.io(value, ).parse end |
.string(value, options = {}) ⇒ Object
call-seq:
XML::Document.string(string)
XML::Document.string(string, :encoding => XML::Encoding::UTF_8,
:options => XML::Parser::Options::NOENT
:base_uri="http://libxml.org") -> XML::Document
Creates a new document from the specified string.
You may provide an optional hash table to control how the parsing is performed. Valid options are:
base_uri - The base url for the parsed document.
encoding - The document encoding, defaults to nil. Valid values
are the encoding constants defined on XML::Encoding.
options - Parser options. Valid values are the constants defined on
XML::Parser::Options. Mutliple options can be combined
by using Bitwise OR (|).
75 76 77 |
# File 'lib/libxml/document.rb', line 75 def self.string(value, = {}) Parser.string(value, ).parse end |
Instance Method Details
#child ⇒ Object
Get this document’s child node.
232 233 234 235 236 237 238 239 240 241 |
# File 'ext/libxml/ruby_xml_document.c', line 232
static VALUE rxml_document_child_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->children == NULL)
return (Qnil);
return rxml_node_wrap(xdoc->children);
}
|
#child? ⇒ Boolean
Determine whether this document has a child node.
249 250 251 252 253 254 255 256 257 258 |
# File 'ext/libxml/ruby_xml_document.c', line 249
static VALUE rxml_document_child_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->children == NULL)
return (Qfalse);
else
return (Qtrue);
}
|
#compression ⇒ Numeric
Obtain this document’s compression mode identifier.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'ext/libxml/ruby_xml_document.c', line 149
static VALUE rxml_document_compression_get(VALUE self)
{
#ifdef HAVE_ZLIB_H
xmlDocPtr xdoc;
int compmode;
Data_Get_Struct(self, xmlDoc, xdoc);
compmode = xmlGetDocCompressMode(xdoc);
if (compmode == -1)
return(Qnil);
else
return(INT2NUM(compmode));
#else
rb_warn("libxml not compiled with zlib support");
return (Qfalse);
#endif
}
|
#compression=(num) ⇒ Object
Set this document’s compression mode.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'ext/libxml/ruby_xml_document.c', line 174
static VALUE rxml_document_compression_set(VALUE self, VALUE num)
{
#ifdef HAVE_ZLIB_H
xmlDocPtr xdoc;
int compmode;
Check_Type(num, T_FIXNUM);
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc == NULL)
{
return(Qnil);
}
else
{
xmlSetDocCompressMode(xdoc, NUM2INT(num));
compmode = xmlGetDocCompressMode(xdoc);
if (compmode == -1)
return(Qnil);
else
return(INT2NUM(compmode));
}
#else
rb_warn("libxml compiled without zlib support");
return (Qfalse);
#endif
}
|
#compression? ⇒ Boolean
Determine whether this document is compressed.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'ext/libxml/ruby_xml_document.c', line 209
static VALUE rxml_document_compression_q(VALUE self)
{
#ifdef HAVE_ZLIB_H
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->compression != -1)
return(Qtrue);
else
return(Qfalse);
#else
rb_warn("libxml compiled without zlib support");
return (Qfalse);
#endif
}
|
#context(nslist = nil) ⇒ Object
Returns a new XML::XPathContext for the document.
call-seq:
document.context(namespaces=nil) -> XPath::Context
Namespaces is an optional array of XML::NS objects
85 86 87 88 89 90 91 |
# File 'lib/libxml/document.rb', line 85 def context(nslist = nil) context = XPath::Context.new(self) context.node = self.root context.register_namespaces_from_node(self.root) context.register_namespaces(nslist) if nslist context end |
#debug ⇒ Object
Print libxml debugging information to stdout. Requires that libxml was compiled with debugging enabled.
268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'ext/libxml/ruby_xml_document.c', line 268
static VALUE rxml_document_debug(VALUE self)
{
#ifdef LIBXML_DEBUG_ENABLED
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
xmlDebugDumpDocument(NULL, xdoc);
return Qtrue;
#else
rb_warn("libxml was compiled without debugging support.")
return Qfalse;
#endif
}
|
#debug_dump ⇒ Object
171 172 173 174 |
# File 'lib/libxml/document.rb', line 171 def debug_dump warn('Document#debug_dump is deprecated. Use Document#debug instead.') self.debug end |
#debug_dump_head ⇒ Object
176 177 178 179 |
# File 'lib/libxml/document.rb', line 176 def debug_dump_head warn('Document#debug_dump_head is deprecated. Use Document#debug instead.') self.debug end |
#debug_format_dump ⇒ Object
181 182 183 184 |
# File 'lib/libxml/document.rb', line 181 def debug_format_dump warn('Document#debug_format_dump is deprecated. Use Document#to_s instead.') self.to_s end |
#docbook_doc? ⇒ Boolean
Specifies if this is an docbook node
152 153 154 |
# File 'lib/libxml/document.rb', line 152 def docbook_doc? node_type == XML::Node::DOCB_DOCUMENT_NODE end |
#document? ⇒ Boolean
Specifies if this is an DOCTYPE node
147 148 149 |
# File 'lib/libxml/document.rb', line 147 def document? node_type == XML::Node::DOCUMENT_NODE end |
#dump ⇒ Object
161 162 163 164 |
# File 'lib/libxml/document.rb', line 161 def dump warn('Document#dump is deprecated. Use Document#to_s instead.') self.to_s end |
#encoding ⇒ XML::Encoding::UTF_8
Returns the LibXML encoding constant specified by this document.
287 288 289 290 291 292 293 294 295 |
# File 'ext/libxml/ruby_xml_document.c', line 287
static VALUE rxml_document_encoding_get(VALUE self)
{
xmlDocPtr xdoc;
const char *xencoding;
Data_Get_Struct(self, xmlDoc, xdoc);
xencoding = (const char*)xdoc->encoding;
return INT2NUM(xmlParseCharEncoding(xencoding));
}
|
#encoding=(XML) ⇒ Object
Set the encoding for this document.
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'ext/libxml/ruby_xml_document.c', line 322
static VALUE rxml_document_encoding_set(VALUE self, VALUE encoding)
{
xmlDocPtr xdoc;
const char* xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(encoding));
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->encoding != NULL)
xmlFree((xmlChar *) xdoc->encoding);
xdoc->encoding = xmlStrdup((xmlChar *)xencoding);
return self;
}
|
#find(xpath, nslist = nil) ⇒ Object
Return the nodes matching the specified xpath expression, optionally using the specified namespace. For more information about working with namespaces, please refer to the XML::XPath documentation.
Parameters:
-
xpath - The xpath expression as a string
-
namespaces - An optional list of namespaces (see XML::XPath for information).
-
Returns - XML::XPath::Object
document.find('/foo', 'xlink:http://www.w3.org/1999/xlink')
IMPORTANT - The returned XML::Node::Set must be freed before its associated document. In a running Ruby program this will happen automatically via Ruby’s mark and sweep garbage collector. However, if the program exits, Ruby does not guarantee the order in which objects are freed (see blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-core/17700). As a result, the associated document may be freed before the node list, which will cause a segmentation fault. To avoid this, use the following (non-ruby like) coding style:
nodes = doc.find('/header')
nodes.each do |node|
... do stuff ...
end
# nodes = nil # GC.start
120 121 122 |
# File 'lib/libxml/document.rb', line 120 def find(xpath, nslist = nil) self.context(nslist).find(xpath) end |
#find_first(xpath, nslist = nil) ⇒ Object
Return the first node matching the specified xpath expression. For more information, please refer to the documentation for XML::Document#find.
127 128 129 |
# File 'lib/libxml/document.rb', line 127 def find_first(xpath, nslist = nil) find(xpath, nslist).first end |
#format_dump ⇒ Object
166 167 168 169 |
# File 'lib/libxml/document.rb', line 166 def format_dump warn('Document#format_dump is deprecated. Use Document#to_s instead.') self.to_s end |
#html_doc? ⇒ Boolean
Specifies if this is an html node
157 158 159 |
# File 'lib/libxml/document.rb', line 157 def html_doc? node_type == XML::Node::HTML_DOCUMENT_NODE end |
#import(node) ⇒ XML::Node
Creates a copy of the node that can be inserted into the current document.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'ext/libxml/ruby_xml_document.c', line 343
static VALUE rxml_document_import(VALUE self, VALUE node)
{
xmlDocPtr xdoc;
xmlNodePtr xnode, xresult;
Data_Get_Struct(self, xmlDoc, xdoc);
Data_Get_Struct(node, xmlNode, xnode);
xresult = xmlDocCopyNode(xnode, xdoc, 1);
if (xresult == NULL)
rxml_raise(&xmlLastError);
return rxml_node_wrap(xresult);
}
|
#last ⇒ Object
Obtain the last node.
365 366 367 368 369 370 371 372 373 374 375 |
# File 'ext/libxml/ruby_xml_document.c', line 365
static VALUE rxml_document_last_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->last == NULL)
return (Qnil);
return rxml_node_wrap(xdoc->last);
}
|
#last? ⇒ Boolean
Determine whether there is a last node.
383 384 385 386 387 388 389 390 391 392 393 |
# File 'ext/libxml/ruby_xml_document.c', line 383
static VALUE rxml_document_last_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->last == NULL)
return (Qfalse);
else
return (Qtrue);
}
|
#next ⇒ Object
Obtain the next node.
401 402 403 404 405 406 407 408 409 410 411 |
# File 'ext/libxml/ruby_xml_document.c', line 401
static VALUE rxml_document_next_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->next == NULL)
return (Qnil);
return rxml_node_wrap(xdoc->next);
}
|
#next? ⇒ Boolean
Determine whether there is a next node.
419 420 421 422 423 424 425 426 427 428 429 |
# File 'ext/libxml/ruby_xml_document.c', line 419
static VALUE rxml_document_next_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->next == NULL)
return (Qfalse);
else
return (Qtrue);
}
|
#type ⇒ Numeric
Obtain this node’s type identifier.
437 438 439 440 441 442 |
# File 'ext/libxml/ruby_xml_document.c', line 437
static VALUE rxml_document_node_type(VALUE self)
{
xmlNodePtr xnode;
Data_Get_Struct(self, xmlNode, xnode);
return (INT2NUM(xnode->type));
}
|
#node_type_name ⇒ Object
Returns this node’s type name
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/libxml/document.rb', line 132 def node_type_name case node_type when XML::Node::DOCUMENT_NODE 'document_xml' when XML::Node::DOCB_DOCUMENT_NODE 'document_docbook' when XML::Node::HTML_DOCUMENT_NODE 'document_html' else raise(UnknownType, "Unknown node type: %n", node.node_type); end end |
#order_elements! ⇒ Object
Call this routine to speed up XPath computation on static documents. This stamps all the element nodes with the document order.
796 797 798 799 800 801 802 |
# File 'ext/libxml/ruby_xml_document.c', line 796
static VALUE rxml_document_order_elements(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
return LONG2FIX(xmlXPathOrderDocElems(xdoc));
}
|
#parent ⇒ Object
Obtain the parent node.
450 451 452 453 454 455 456 457 458 459 460 |
# File 'ext/libxml/ruby_xml_document.c', line 450
static VALUE rxml_document_parent_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->parent == NULL)
return (Qnil);
return rxml_node_wrap(xdoc->parent);
}
|
#parent? ⇒ Boolean
Determine whether there is a parent node.
468 469 470 471 472 473 474 475 476 477 478 |
# File 'ext/libxml/ruby_xml_document.c', line 468
static VALUE rxml_document_parent_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->parent == NULL)
return (Qfalse);
else
return (Qtrue);
}
|
#prev ⇒ Object
Obtain the previous node.
486 487 488 489 490 491 492 493 494 495 496 |
# File 'ext/libxml/ruby_xml_document.c', line 486
static VALUE rxml_document_prev_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->prev == NULL)
return (Qnil);
return rxml_node_wrap(xdoc->prev);
}
|
#prev? ⇒ Boolean
Determine whether there is a previous node.
504 505 506 507 508 509 510 511 512 513 514 |
# File 'ext/libxml/ruby_xml_document.c', line 504
static VALUE rxml_document_prev_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->prev == NULL)
return (Qfalse);
else
return (Qtrue);
}
|
#rb_encoding ⇒ Encoding
Returns the Ruby encoding specified by this document (available on Ruby 1.9.x and higher).
305 306 307 308 309 310 311 312 313 314 |
# File 'ext/libxml/ruby_xml_document.c', line 305
static VALUE rxml_document_rb_encoding_get(VALUE self)
{
xmlDocPtr xdoc;
const char *xencoding;
VALUE encoding;
Data_Get_Struct(self, xmlDoc, xdoc);
xencoding = (const char*)xdoc->encoding;
return rxml_xml_encoding_to_rb_encoding(mXMLEncoding, xmlParseCharEncoding(xencoding));
}
|
#reader ⇒ Object
186 187 188 189 |
# File 'lib/libxml/document.rb', line 186 def reader warn('Document#reader is deprecated. Use XML::Reader.document(self) instead.') XML::Reader.document(self) end |
#root ⇒ Object
Obtain the root node.
522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'ext/libxml/ruby_xml_document.c', line 522
static VALUE rxml_document_root_get(VALUE self)
{
xmlDocPtr xdoc;
xmlNodePtr root;
Data_Get_Struct(self, xmlDoc, xdoc);
root = xmlDocGetRootElement(xdoc);
if (root == NULL)
return (Qnil);
return rxml_node_wrap(root);
}
|
#root=(node) ⇒ Object
Set the root node.
543 544 545 546 547 548 549 550 551 552 553 554 555 556 |
# File 'ext/libxml/ruby_xml_document.c', line 543
static VALUE rxml_document_root_set(VALUE self, VALUE node)
{
xmlDocPtr xdoc;
xmlNodePtr xroot, xnode;
if (rb_obj_is_kind_of(node, cXMLNode) == Qfalse)
rb_raise(rb_eTypeError, "must pass an XML::Node type object");
Data_Get_Struct(self, xmlDoc, xdoc);
Data_Get_Struct(node, xmlNode, xnode);
xroot = xmlDocSetRootElement(xdoc, xnode);
return node;
}
|
#save(filename) ⇒ Integer #save(filename, : indent) ⇒ true
Saves a document to a file. You may provide an optional hash table to control how the string is generated. Valid options are:
:indent - Specifies if the string should be indented. The default value is true. Note that indentation is only added if both :indent is true and XML.indent_tree_output is true. If :indent is set to false, then both indentation and line feeds are removed from the result.
:encoding - Specifies the output encoding of the string. It defaults to the original encoding of the document (see #encoding. To override the orginal encoding, use one of the XML::Encoding encoding constants.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'ext/libxml/ruby_xml_document.c', line 575
static VALUE rxml_document_save(int argc, VALUE *argv, VALUE self)
{
VALUE options = Qnil;
VALUE filename = Qnil;
xmlDocPtr xdoc;
int indent = 1;
const char *xfilename;
const char *xencoding;
int length;
rb_scan_args(argc, argv, "11", &filename, &options);
Check_Type(filename, T_STRING);
xfilename = StringValuePtr(filename);
Data_Get_Struct(self, xmlDoc, xdoc);
xencoding = xdoc->encoding;
if (!NIL_P(options))
{
VALUE rencoding, rindent;
Check_Type(options, T_HASH);
rencoding = rb_hash_aref(options, ID2SYM(rb_intern("encoding")));
rindent = rb_hash_aref(options, ID2SYM(rb_intern("indent")));
if (rindent == Qfalse)
indent = 0;
if (rencoding != Qnil)
{
xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
if (!xencoding)
rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
}
}
length = xmlSaveFormatFileEnc(xfilename, xdoc, xencoding, indent);
if (length == -1)
rxml_raise(&xmlLastError);
return (INT2NUM(length));
}
|
#standalone? ⇒ Boolean
Determine whether this is a standalone document.
625 626 627 628 629 630 631 632 633 634 |
# File 'ext/libxml/ruby_xml_document.c', line 625
static VALUE rxml_document_standalone_q(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->standalone)
return (Qtrue);
else
return (Qfalse);
}
|
#to_s ⇒ Object #to_s(: indent) ⇒ true
Converts a document, and all of its children, to a string representation. You may provide an optional hash table to control how the string is generated. Valid options are:
:indent - Specifies if the string should be indented. The default value is true. Note that indentation is only added if both :indent is true and XML.indent_tree_output is true. If :indent is set to false, then both indentation and line feeds are removed from the result.
:encoding - Specifies the output encoding of the string. It defaults to XML::Encoding::UTF8. To change it, use one of the XML::Encoding encoding constants.
653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'ext/libxml/ruby_xml_document.c', line 653
static VALUE rxml_document_to_s(int argc, VALUE *argv, VALUE self)
{
VALUE result;
VALUE options = Qnil;
xmlDocPtr xdoc;
int indent = 1;
const char *xencoding = "UTF-8";
xmlChar *buffer;
int length;
rb_scan_args(argc, argv, "01", &options);
if (!NIL_P(options))
{
VALUE rencoding, rindent;
Check_Type(options, T_HASH);
rencoding = rb_hash_aref(options, ID2SYM(rb_intern("encoding")));
rindent = rb_hash_aref(options, ID2SYM(rb_intern("indent")));
if (rindent == Qfalse)
indent = 0;
if (rencoding != Qnil)
{
xencoding = xmlGetCharEncodingName((xmlCharEncoding)NUM2INT(rencoding));
if (!xencoding)
rb_raise(rb_eArgError, "Unknown encoding value: %d", NUM2INT(rencoding));
}
}
Data_Get_Struct(self, xmlDoc, xdoc);
xmlDocDumpFormatMemoryEnc(xdoc, &buffer, &length, xencoding, indent);
result = rxml_str_new2((const char*) buffer, xencoding);
xmlFree(buffer);
return result;
}
|
#url ⇒ Object
Obtain this document’s source URL, if any.
697 698 699 700 701 702 703 704 705 706 |
# File 'ext/libxml/ruby_xml_document.c', line 697
static VALUE rxml_document_url_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->URL == NULL)
return (Qnil);
else
return (rxml_str_new2((const char*) xdoc->URL, xdoc->encoding));
}
|
#validate(dtd) ⇒ Object
Validate this document against the specified XML::DTD.
888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'ext/libxml/ruby_xml_document.c', line 888
static VALUE rxml_document_validate_dtd(VALUE self, VALUE dtd)
{
VALUE error = Qnil;
xmlValidCtxt ctxt;
xmlDocPtr xdoc;
xmlDtdPtr xdtd;
Data_Get_Struct(self, xmlDoc, xdoc);
Data_Get_Struct(dtd, xmlDtd, xdtd);
ctxt.userData = &error;
ctxt.error = (xmlValidityErrorFunc) LibXML_validity_error;
ctxt.warning = (xmlValidityWarningFunc) LibXML_validity_warning;
ctxt.nodeNr = 0;
ctxt.nodeTab = NULL;
ctxt.vstateNr = 0;
ctxt.vstateTab = NULL;
if (xmlValidateDtd(&ctxt, xdoc, xdtd))
{
return (Qtrue);
}
else
{
rxml_raise(&xmlLastError);
return Qfalse;
}
}
|
#validate_schema(relaxng) ⇒ Object
Validate this document against the specified XML::RelaxNG.
If a block is provided it is used as an error handler for validaten errors. The block is called with two argument, the message and a flag indication if the message is an error (true) or a warning (false).
853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 |
# File 'ext/libxml/ruby_xml_document.c', line 853
static VALUE rxml_document_validate_relaxng(VALUE self, VALUE relaxng)
{
xmlRelaxNGValidCtxtPtr vptr;
xmlDocPtr xdoc;
xmlRelaxNGPtr xrelaxng;
int is_invalid;
Data_Get_Struct(self, xmlDoc, xdoc);
Data_Get_Struct(relaxng, xmlRelaxNG, xrelaxng);
vptr = xmlRelaxNGNewValidCtxt(xrelaxng);
xmlRelaxNGSetValidErrors(vptr,
(xmlRelaxNGValidityErrorFunc) LibXML_validity_error,
(xmlRelaxNGValidityWarningFunc) LibXML_validity_warning, NULL);
is_invalid = xmlRelaxNGValidateDoc(vptr, xdoc);
xmlRelaxNGFreeValidCtxt(vptr);
if (is_invalid)
{
rxml_raise(&xmlLastError);
return Qfalse;
}
else
{
return Qtrue;
}
}
|
#validate_schema(schema) ⇒ Object
Validate this document against the specified XML::Schema.
If a block is provided it is used as an error handler for validaten errors. The block is called with two argument, the message and a flag indication if the message is an error (true) or a warning (false).
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 |
# File 'ext/libxml/ruby_xml_document.c', line 814
static VALUE rxml_document_validate_schema(VALUE self, VALUE schema)
{
xmlSchemaValidCtxtPtr vptr;
xmlDocPtr xdoc;
xmlSchemaPtr xschema;
int is_invalid;
Data_Get_Struct(self, xmlDoc, xdoc);
Data_Get_Struct(schema, xmlSchema, xschema);
vptr = xmlSchemaNewValidCtxt(xschema);
xmlSchemaSetValidErrors(vptr,
(xmlSchemaValidityErrorFunc) LibXML_validity_error,
(xmlSchemaValidityWarningFunc) LibXML_validity_warning, NULL);
is_invalid = xmlSchemaValidateDoc(vptr, xdoc);
xmlSchemaFreeValidCtxt(vptr);
if (is_invalid)
{
rxml_raise(&xmlLastError);
return Qfalse;
}
else
{
return Qtrue;
}
}
|
#version ⇒ Object
Obtain the XML version specified by this document.
714 715 716 717 718 719 720 721 722 723 |
# File 'ext/libxml/ruby_xml_document.c', line 714
static VALUE rxml_document_version_get(VALUE self)
{
xmlDocPtr xdoc;
Data_Get_Struct(self, xmlDoc, xdoc);
if (xdoc->version == NULL)
return (Qnil);
else
return (rxml_str_new2((const char*) xdoc->version, xdoc->encoding));
}
|
#xhtml? ⇒ Boolean
Determine whether this is an XHTML document.
731 732 733 734 735 736 737 738 739 740 741 |
# File 'ext/libxml/ruby_xml_document.c', line 731
static VALUE rxml_document_xhtml_q(VALUE self)
{
xmlDocPtr xdoc;
xmlDtdPtr xdtd;
Data_Get_Struct(self, xmlDoc, xdoc);
xdtd = xmlGetIntSubset(xdoc);
if (xdtd != NULL && xmlIsXHTML(xdtd->SystemID, xdtd->ExternalID) > 0)
return (Qtrue);
else
return (Qfalse);
}
|
#xinclude ⇒ Numeric
Process xinclude directives in this document.
749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'ext/libxml/ruby_xml_document.c', line 749
static VALUE rxml_document_xinclude(VALUE self)
{
#ifdef LIBXML_XINCLUDE_ENABLED
xmlDocPtr xdoc;
int ret;
Data_Get_Struct(self, xmlDoc, xdoc);
ret = xmlXIncludeProcess(xdoc);
if (ret >= 0)
{
return(INT2NUM(ret));
}
else
{
rxml_raise(&xmlLastError);
return Qnil;
}
#else
rb_warn(
"libxml was compiled without XInclude support. Please recompile libxml and ruby-libxml");
return (Qfalse);
#endif
}
|